summaryrefslogtreecommitdiffhomepage
path: root/dev/lib/logic/math.hpp
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@nekernel.org>2025-08-27 12:28:55 +0200
committerAmlal El Mahrouss <amlal@nekernel.org>2025-08-27 12:31:41 +0200
commitb4f35dbe44e07b597c3e7bb6d7562757069a7cb4 (patch)
tree88af99a2cca9c514536b4b61785fa67b3543429c /dev/lib/logic/math.hpp
parentfbda49eea45ce08b9a72744c04761e1556ebd2fa (diff)
feat: moved SOCL into OCL, without SNU's baggage.v1.0.41
Signed-off-by: Amlal El Mahrouss <amlal@nekernel.org>
Diffstat (limited to 'dev/lib/logic/math.hpp')
-rw-r--r--dev/lib/logic/math.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/dev/lib/logic/math.hpp b/dev/lib/logic/math.hpp
index 155251b..e796eae 100644
--- a/dev/lib/logic/math.hpp
+++ b/dev/lib/logic/math.hpp
@@ -1,7 +1,7 @@
/*
* File: math.hpp
* Purpose: Mathematics c++ header.
- * Author: Amlal El Mahrouss (founder@snu.systems)
+ * Author: Amlal El Mahrouss (amlal@nekernel.org)
* Copyright 2025, Amlal El Mahrouss.
*/
@@ -9,7 +9,7 @@
#include <cmath>
-namespace snu
+namespace ocl
{
template <std::size_t T>
struct is_non_boolean_integer final
@@ -32,4 +32,4 @@ namespace snu
constexpr inline auto not_a_number = NAN;
constexpr inline auto positive_infinity = INFINITY;
constexpr inline auto negative_infinity = -positive_infinity;
-} // namespace snu \ No newline at end of file
+} // namespace ocl \ No newline at end of file